@@ -15,7 +15,7 @@ Airflow config
 import socket
 
 import airflow
-from airflow import configuration
+from airflow.configuration import conf
 from openmetadata import __version__
 
 REST_API_ENDPOINT = "/rest_api/api"
@@ -26,12 +26,8 @@ AIRFLOW_VERSION = airflow.__version__
 REST_API_PLUGIN_VERSION = __version__
 
 # Getting configurations from airflow.cfg file
-AIRFLOW_WEBSERVER_BASE_URL = configuration.get("webserver", "BASE_URL")
-AIRFLOW_DAGS_FOLDER = configuration.get("core", "DAGS_FOLDER")
-DAG_RUNNER_TEMPLATE = configuration.get(
-    "openmetadata_airflow_apis", "DAG_RUNNER_TEMPLATE"
-)
+AIRFLOW_WEBSERVER_BASE_URL = conf.get("webserver", "BASE_URL")
+AIRFLOW_DAGS_FOLDER = conf.get("core", "DAGS_FOLDER")
+DAG_RUNNER_TEMPLATE = conf.get("openmetadata_airflow_apis", "DAG_RUNNER_TEMPLATE")
 # Path to store the JSON configurations we receive via REST
-DAG_GENERATED_CONFIGS = configuration.get(
-    "openmetadata_airflow_apis", "DAG_GENERATED_CONFIGS"
-)
+DAG_GENERATED_CONFIGS = conf.get("openmetadata_airflow_apis", "DAG_GENERATED_CONFIGS")
